@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -21,6 +21,7 @@ from ZODB.POSException import ConflictError
 import transaction
 
 import zope.component
+import zope.component.interfaces
 from zope.component import queryMultiAdapter
 from zope.event import notify
 from zope.security.interfaces import Unauthorized
@@ -32,6 +33,7 @@ from zope.publisher.interfaces import NotFound, Retry
 from zope.security.management import newInteraction, endInteraction
 from zope.security.checker import ProxyFactory
 from zope.security.proxy import removeSecurityProxy
+from zope.traversing.interfaces import BeforeTraverseEvent
 from zope.traversing.interfaces import IPhysicallyLocatable
 from zope.traversing.interfaces import IEtcNamespace
 from zope.traversing.interfaces import TraversalError
@@ -41,13 +43,12 @@ from zope.error.interfaces import IErrorReportingUtility
 
 import zope.authentication.interfaces
 from zope.browser.interfaces import ISystemErrorView
-from zope.app.publication.interfaces import BeforeTraverseEvent
-from zope.app.publication.interfaces import EndRequestEvent
 from zope.publisher.defaultview import queryDefaultViewName
+from zope.publisher.interfaces import EndRequestEvent, StartRequestEvent
 from zope.authentication.interfaces import IUnauthenticatedPrincipal
 from zope.authentication.interfaces import IFallbackUnauthenticatedPrincipal
 from zope.authentication.interfaces import IAuthentication
-from zope.location.interfaces import ISite
+
 
 class Cleanup(object):
 
@@ -66,6 +67,7 @@ class Cleanup(object):
                 "Cleanup without request close")
             self._f()
 
+
 class ZopePublication(object):
     """Base Zope publication specification."""
     implements(IPublication)
@@ -85,6 +87,7 @@ class ZopePublication(object):
         return ProxyFactory(ob)
 
     def beforeTraversal(self, request):
+        notify(StartRequestEvent(request))
         # Try to authenticate against the root authentication utility.
         auth = zope.component.getGlobalSiteManager().getUtility(
             zope.authentication.interfaces.IAuthentication)
@@ -106,7 +109,7 @@ class ZopePublication(object):
             # Note that beforeTraversal guarentees that user is not None.
             return
 
-        if not ISite.providedBy(ob):
+        if not zope.component.interfaces.ISite.providedBy(ob):
             # We won't find an authentication utility here, so give up.
             return
 
